@@ -2,16 +2,18 @@ package App::Yath::Command::ui;
 use strict;
 use warnings;
 
-our $VERSION = '0.000028';
+our $VERSION = '0.000029';
 
 use Test2::Util qw/pkg_to_file/;
 
-use Test2::Harness::UI::Util qw/share_dir share_file/;
+use Test2::Harness::UI::Util qw/share_dir share_file dbd_driver qdb_driver/;
 
 use Test2::Harness::UI::Config;
 use Test2::Harness::UI::Importer;
 use Test2::Harness::UI;
 
+use Test2::Harness::Util::UUID qw/gen_uuid/;
+
 use DBIx::QuickDB;
 use Plack::Builder;
 use Plack::App::Directory;
@@ -27,6 +29,13 @@ include_options(
     'App::Yath::Options::PreCommand',
 );
 
+option_group {prefix => 'ui', category => "UI Options"} => sub {
+    option schema => (
+        type => 's',
+        default => 'PostgreSQL',
+    );
+};
+
 sub summary { "Launch a standalone Test2-Harness-UI server for a log file" }
 
 sub group { 'log' }
@@ -41,7 +50,11 @@ sub description {
 sub run {
     my $self = shift;
 
-    my $args     = $self->args;
+    my $args = $self->args;
+    my $settings = $self->settings;
+
+    my $schema = $settings->ui->schema;
+    require(pkg_to_file("Test2::Harness::UI::Schema::$schema"));
 
     shift @$args if @$args && $args->[0] eq '--';
 
@@ -49,11 +62,11 @@ sub run {
     die "'$self->{+LOG_FILE}' is not a valid log file" unless -f $self->{+LOG_FILE};
     die "'$self->{+LOG_FILE}' does not look like a log file" unless $self->{+LOG_FILE} =~ m/\.jsonl(\.(gz|bz2))?$/;
 
-    my $db = DBIx::QuickDB->build_db(harness_ui => {driver => 'PostgreSQL'});
+    my $db = DBIx::QuickDB->build_db(harness_ui => {driver => qdb_driver($schema), dbd_driver => dbd_driver($schema)});
 
     my $dbh = $db->connect('quickdb', AutoCommit => 1, RaiseError => 1);
     $dbh->do('CREATE DATABASE harness_ui') or die "Could not create db " . $dbh->errstr;
-    $db->load_sql(harness_ui => share_file('schema/postgresql.sql'));
+    $db->load_sql(harness_ui => share_file("schema/$schema.sql"));
     my $dsn = $db->connect_string('harness_ui');
     $dbh = undef;
 
@@ -68,23 +81,22 @@ sub run {
         single_run  => 1,
     );
 
-    my $user = $config->schema->resultset('User')->create({username => 'root', password => 'root', realname => 'root'});
-    my $proj = $config->schema->resultset('Project')->create({name => 'default'});
+    my $user = $config->schema->resultset('User')->create({username => 'root', password => 'root', realname => 'root', user_id => gen_uuid()});
+    my $proj = $config->schema->resultset('Project')->create({name => 'default', project_id => gen_uuid()});
 
-    open(my $lf, '<', $self->{+LOG_FILE}) or die "Could no open log file: $!";
-    $config->schema->resultset('Run')->create(
-        {
-            user_id    => $user->user_id,
-            mode       => 'complete',
-            status     => 'pending',
-            project_id => $proj->project_id,
+    $config->schema->resultset('Run')->create({
+        run_id     => gen_uuid(),
+        user_id    => $user->user_id,
+        mode       => 'complete',
+        status     => 'pending',
+        project_id => $proj->project_id,
 
-            log_file => {
-                name => $self->{+LOG_FILE},
-                data => do { local $/; <$lf> },
-            },
-        }
-    );
+        log_file => {
+            log_file_id => gen_uuid(),
+            name        => $self->{+LOG_FILE},
+            local_file  => $self->{+LOG_FILE},
+        },
+    });
 
     Test2::Harness::UI::Importer->new(config => $config)->run(1);
 
