@@ -2,9 +2,9 @@ package Test2::Harness::UI::Config;
 use strict;
 use warnings;
 
-our $VERSION = '0.000028';
+our $VERSION = '0.000029';
 
-use Test2::Util qw/get_tid/;
+use Test2::Util qw/get_tid pkg_to_file/;
 
 use Carp qw/croak/;
 
@@ -46,6 +46,11 @@ sub schema {
 
     return $self->{+_SCHEMA} if $self->{+_SCHEMA};
 
+    unless ($Test2::Harness::UI::Schema::LOADED) {
+        my $schema = $ENV{YATH_UI_SCHEMA} //= 'PostgreSQL';
+        require(pkg_to_file("Test2::Harness::UI::Schema::$schema"));
+    }
+
     require Test2::Harness::UI::Schema;
 
     return $self->{+_SCHEMA} = Test2::Harness::UI::Schema->connect({dbh_maker => sub { $self->connect }});
